Module blaxel.core.client.models.jobs_chart_value
=================================================

Classes
-------

`JobsChartValue(timestamp: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, value: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>)`
:   Jobs CPU usage
    
    Attributes:
        timestamp (Union[Unset, str]): Metric timestamp
        value (Union[Unset, float]): Metric value
    
    Method generated by attrs for class JobsChartValue.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `timestamp: blaxel.core.client.types.Unset | str`
    :

    `value: blaxel.core.client.types.Unset | float`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :